@@ -99,8 +99,9 @@ compare (const gchar * pattern, const gchar * string, gint regex,
 	  return_value = fnmatch (pattern, my_string, 0);
 	}
     }
-    else {
-    	g_error("Error on the string comparation mode\n");
+  else
+    {
+      g_error ("Error on the string comparation mode\n");
     }
   return (return_value);
 }
@@ -236,6 +237,7 @@ extract_field (const gchar * string, const gchar * separator, GArray * fields)
       regfree (r);
       return NULL;
     }
+  g_string_free (pattern, TRUE);
   no_sub = r->re_nsub + 1;	/* How many matches are there in a line? */
   matches = (regmatch_t *) g_malloc (sizeof (regmatch_t) * no_sub);
 
@@ -262,12 +264,15 @@ extract_field (const gchar * string, const gchar * separator, GArray * fields)
 				     (tmp_list,
 				      g_array_index (fields, gint, i))));
 	}
-      g_ptr_array_free (tmp_list, TRUE);
-      return (result_list);
+      for (i = 0; i < tmp_list->len; i++)
+	{
+	  g_free (g_ptr_array_index (tmp_list, i));
+	}
     }
   else
     {
-      g_ptr_array_free (tmp_list, FALSE);
-      return (NULL);
+      result_list = NULL;
     }
+  g_ptr_array_free (tmp_list, TRUE);
+  return (result_list);
 }
