@@ -177,8 +177,8 @@ static const short yyrline[] = { 0,
    236,   237,   240,   272,   295,   315,   350,   378,   389,   400,
    411,   421,   431,   442,   452,   462,   473,   484,   495,   506,
    517,   530,   546,   557,   568,   579,   590,   601,   612,   623,
-   634,   645,   656,   665,   676,   687,   698,   709,   720,   731,
-   743,   760,   761,   764,   765
+   634,   645,   656,   665,   676,   694,   705,   716,   727,   738,
+   750,   767,   768,   771,   772
 };
 #endif
 
@@ -1501,15 +1501,22 @@ case 75:
 #line 677 "config_parse.y"
 {{
 			KEY_VALUE *r;
+#if defined(__DEBUG__)
+  GML_set_mode_active ();
+  GML_log_point(1,"lecture");
+#endif
 
 			r = (KEY_VALUE*)g_malloc(sizeof(KEY_VALUE));
 			r->key = g_string_new("RecentFile");
 			r->value = yyvsp[0].gstring;
 			yyval.kv = r;
+#if defined(__DEBUG__)
+  GML_set_mode_passive ();
+#endif
 		};
     break;}
 case 76:
-#line 688 "config_parse.y"
+#line 695 "config_parse.y"
 {{
 			KEY_VALUE *r;
 
@@ -1520,7 +1527,7 @@ case 76:
 		};
     break;}
 case 77:
-#line 699 "config_parse.y"
+#line 706 "config_parse.y"
 {{
 			KEY_VALUE *r;
 
@@ -1531,7 +1538,7 @@ case 77:
 		};
     break;}
 case 78:
-#line 710 "config_parse.y"
+#line 717 "config_parse.y"
 {{
 			KEY_VALUE *r;
 
@@ -1542,7 +1549,7 @@ case 78:
 		};
     break;}
 case 79:
-#line 721 "config_parse.y"
+#line 728 "config_parse.y"
 {{
 			KEY_VALUE *r;
 
@@ -1553,7 +1560,7 @@ case 79:
 		};
     break;}
 case 80:
-#line 732 "config_parse.y"
+#line 739 "config_parse.y"
 {{
 			KEY_VALUE *r;
 
@@ -1565,7 +1572,7 @@ case 80:
 		};
     break;}
 case 81:
-#line 744 "config_parse.y"
+#line 751 "config_parse.y"
 {{
 			KEY_VALUE *r;
 
@@ -1580,19 +1587,19 @@ case 81:
 		};
     break;}
 case 82:
-#line 760 "config_parse.y"
+#line 767 "config_parse.y"
 { yyval.glist = g_list_append(NULL, yyvsp[0].gstring); ;
     break;}
 case 83:
-#line 761 "config_parse.y"
+#line 768 "config_parse.y"
 { yyval.glist = g_list_prepend(yyvsp[0].glist, yyvsp[-1].gstring ); ;
     break;}
 case 84:
-#line 764 "config_parse.y"
+#line 771 "config_parse.y"
 { yyval.gstring = g_string_new(yyvsp[0].string); ;
     break;}
 case 85:
-#line 765 "config_parse.y"
+#line 772 "config_parse.y"
 { 
 							gchar *s;
 							GString *g;
@@ -1824,7 +1831,7 @@ yyerrhandle:
     }
   return 1;
 }
-#line 805 "config_parse.y"
+#line 812 "config_parse.y"
 
 
 int
@@ -1896,9 +1903,6 @@ init_config (GtkWidget * w)
   gchar *path;
   GString *tmpstr;
 
-#if defined(__DEBUG__)
-  GML_log_point (5, "Entering init_config()");
-#endif
   conf_file = g_string_new (g_get_home_dir ());
   conf_file =
     g_string_append (conf_file, USER_CONFIG_DIR "/" USER_CONFIG_FILE);
@@ -1964,10 +1968,8 @@ init_config (GtkWidget * w)
       my_config->mainwindow_h = 480;
       my_config->mainwindow_save_xywh = FALSE;
       my_config->sort_column = 0;
+      my_config->currently_displayed_recent_files = 0;
 
-#if defined(__DEBUG__)
-      GML_log_point (5, "init_config(): parsing config file");
-#endif
       /* Parse the config file */
       yyrestart (rcfile);
       yyparse ();
@@ -1975,9 +1977,6 @@ init_config (GtkWidget * w)
 
       /* Fills some fields of my_config with the parsed data */
 
-#if defined(__DEBUG__)
-      GML_log_point (5, "init_config(): reading parsed data");
-#endif
       glist_ptr1 = local_config;
       while (glist_ptr1)
 	{
@@ -2004,10 +2003,6 @@ init_config (GtkWidget * w)
 		      g_string_free (tmpstr, TRUE);
 		      if (mime)
 			{
-#if defined(__DEBUG__)
-			  GML_malloc_forget (mime);
-#endif
-
 			  g_tree_insert (my_config->mime_icons, mime, pix);
 			}
 		    }
@@ -2037,11 +2032,9 @@ init_config (GtkWidget * w)
 		      g_tree_insert (my_config->mime_icons,
 				     (mime = g_strdup (
 						       ((GString
-							 *) (gl2->data))->
-						       str)), pix);
-#if defined(__DEBUG__)
-		      GML_malloc_forget (mime);
-#endif
+							 *) (gl2->
+							     data))->str)),
+				     pix);
 		    }
 		  g_string_free (gl2->data, TRUE);
 		  gl2 = g_list_next (gl2);
@@ -2058,12 +2051,8 @@ init_config (GtkWidget * w)
 	      my_config->default_file_pix = new_pix_from_filename (w, style,
 								   (path =
 								    g_strdup
-								    (gs->
-								     str)),
+								    (gs->str)),
 								   my_config);
-#if defined(__DEBUG__)
-	      GML_malloc_forget (path);
-#endif
 	      g_string_free (gs, TRUE);
 	      NEXT_TOKEN;
 	    }
@@ -2075,9 +2064,6 @@ init_config (GtkWidget * w)
 								   g_strdup
 								   (gs->str)),
 								  my_config);
-#if defined(__DEBUG__)
-	      GML_malloc_forget (path);
-#endif
 	      g_string_free (gs, TRUE);
 	      NEXT_TOKEN;
 	    }
@@ -2087,12 +2073,8 @@ init_config (GtkWidget * w)
 	      my_config->default_disk_pix = new_pix_from_filename (w, style,
 								   (path =
 								    g_strdup
-								    (gs->
-								     str)),
+								    (gs->str)),
 								   my_config);
-#if defined(__DEBUG__)
-	      GML_malloc_forget (path);
-#endif
 	      g_string_free (gs, TRUE);
 	      NEXT_TOKEN;
 	    }
@@ -2105,12 +2087,8 @@ init_config (GtkWidget * w)
 									 (path
 									  =
 									  g_strdup
-									  (gs->
-									   str)),
+									  (gs->str)),
 									 my_config);
-#if defined(__DEBUG__)
-	      GML_malloc_forget (path);
-#endif
 	      g_string_free (gs, TRUE);
 	      NEXT_TOKEN;
 	    }
@@ -2122,9 +2100,6 @@ init_config (GtkWidget * w)
 								   g_strdup
 								   (gs->str)),
 								  my_config);
-#if defined(__DEBUG__)
-	      GML_malloc_forget (path);
-#endif
 	      g_string_free (gs, TRUE);
 	      NEXT_TOKEN;
 	    }
@@ -2134,9 +2109,6 @@ init_config (GtkWidget * w)
 	      my_config->default_opened_dir_pix =
 		new_pix_from_filename (w, style, (path = g_strdup (gs->str)),
 				       my_config);
-#if defined(__DEBUG__)
-	      GML_malloc_forget (path);
-#endif
 	      g_string_free (gs, TRUE);
 	      NEXT_TOKEN;
 	    }
@@ -2146,9 +2118,6 @@ init_config (GtkWidget * w)
 	      my_config->default_opened_disk_pix =
 		new_pix_from_filename (w, style, (path = g_strdup (gs->str)),
 				       my_config);
-#if defined(__DEBUG__)
-	      GML_malloc_forget (path);
-#endif
 	      g_string_free (gs, TRUE);
 	      NEXT_TOKEN;
 	    }
@@ -2158,9 +2127,6 @@ init_config (GtkWidget * w)
 	      my_config->default_opened_vfs_pix =
 		new_pix_from_filename (w, style, (path = g_strdup (gs->str)),
 				       my_config);
-#if defined(__DEBUG__)
-	      GML_malloc_forget (path);
-#endif
 	      g_string_free (gs, TRUE);
 	      NEXT_TOKEN;
 	    }
@@ -2238,20 +2204,8 @@ init_config (GtkWidget * w)
 	    {
 	      gs = GET_TOKEN;
 	      g_tree_insert (my_config->mime_extensions,
-			     ((MIME_EXTENSIONS *) ((KEY_VALUE *) gs)->
-			      value)->mime->str, ((KEY_VALUE *) gs)->value);
-#if defined(__DEBUG__)
-	      GML_malloc_forget (
-				 ((MIME_EXTENSIONS
-				   *) ((KEY_VALUE *) gs)->value)->mime);
-	      GML_malloc_forget (
-				 ((MIME_EXTENSIONS
-				   *) ((KEY_VALUE *) gs)->value)->prog);
-	      GML_malloc_forget (
-				 ((MIME_EXTENSIONS
-				   *) ((KEY_VALUE *) gs)->value)->arg);
-	      GML_malloc_forget (((KEY_VALUE *) gs)->value);
-#endif
+			     ((MIME_EXTENSIONS *) ((KEY_VALUE *) gs)->value)->
+			     mime->str, ((KEY_VALUE *) gs)->value);
 	      g_free (gs);
 	      NEXT_TOKEN;
 	    }
@@ -2275,11 +2229,6 @@ init_config (GtkWidget * w)
 		((MIME_EXTENSIONS *) gs)->arg;
 	      my_config->default_information_plugin->state =
 		((MIME_EXTENSIONS *) gs)->state;
-#if defined(__DEBUG__)
-	      GML_malloc_forget (my_config->default_information_plugin);
-	      GML_malloc_forget (my_config->default_information_plugin->prog);
-	      GML_malloc_forget (my_config->default_information_plugin->arg);
-#endif
 	      g_free (gs);
 	      NEXT_TOKEN;
 	    }
@@ -2299,22 +2248,6 @@ init_config (GtkWidget * w)
 		{
 		  g_tree_insert (my_config->mime_vfs_extensions, mime,
 				 ((KEY_VALUE *) gs)->value);
-#if defined(__DEBUG__)
-		  GML_malloc_forget (((MIME_VFS_EXTENSIONS
-				       *) ((KEY_VALUE *) gs)->value)->mime);
-		  GML_malloc_forget (((MIME_VFS_EXTENSIONS
-				       *) ((KEY_VALUE *) gs)->value)->prog);
-		  GML_malloc_forget (((MIME_VFS_EXTENSIONS
-				       *) ((KEY_VALUE *) gs)->value)->args);
-		  GML_malloc_forget (((MIME_VFS_EXTENSIONS
-				       *) ((KEY_VALUE *) gs)->
-				      value)->separator);
-		  GML_malloc_forget (
-				     ((MIME_VFS_EXTENSIONS
-				       *) ((KEY_VALUE *) gs)->
-				      value)->date_format);
-		  GML_malloc_forget (((KEY_VALUE *) gs)->value);
-#endif
 		  g_free (gs);
 		}
 	      NEXT_TOKEN;
@@ -2330,9 +2263,6 @@ init_config (GtkWidget * w)
 						 *) (gl1->data))->str)),
 			     gl2->data);
 
-#if defined(__DEBUG__)
-	      GML_malloc_forget (mime);
-#endif
 	      g_string_free (gl1->data, TRUE);
 
 	      g_list_free (gl1);
@@ -2375,6 +2305,10 @@ init_config (GtkWidget * w)
 	    }
 	  else if (IS_TOKEN ("RecentFile"))
 	    {
+#if defined(__DEBUG__)
+	      GML_set_mode_active ();
+	      GML_log_point (1, "config");
+#endif
 	      gs = GET_TOKEN;
 	      my_config->recent_files =
 		add_file_to_recent_files (my_config->recent_files,
@@ -2382,6 +2316,9 @@ init_config (GtkWidget * w)
 					  gs->str);
 	      g_string_free (gs, TRUE);
 	      NEXT_TOKEN;
+#if defined(__DEBUG__)
+	      GML_set_mode_passive ();
+#endif
 	    }
 	  else if (IS_TOKEN ("RecentFilesMax"))
 	    {
@@ -2517,38 +2454,12 @@ init_config (GtkWidget * w)
 	  my_config->default_information_plugin->prog = g_string_new ("");
 	  my_config->default_information_plugin->arg = g_string_new ("");
 	  my_config->default_information_plugin->state = FALSE;
-#if defined(__DEBUG__)
-	  GML_malloc_forget (my_config->default_information_plugin);
-	  GML_malloc_forget (my_config->default_information_plugin->prog);
-	  GML_malloc_forget (my_config->default_information_plugin->arg);
-#endif
 	}
-#if defined(__DEBUG__)
-      GML_malloc_forget (my_config->mount);
-      GML_malloc_forget (my_config->umount);
-      GML_malloc_forget (my_config->eject_prog);
-      GML_malloc_forget (my_config->mount_point);
-      GML_malloc_forget (my_config->date_format);
-      if (my_config->recent_files)
-	{
-	  GList *GML_gl = my_config->recent_files;
-	  while (GML_gl)
-	    {
-	      GML_malloc_forget (((RECENT_FILE *) (GML_gl->data))->fullname);
-	      GML_malloc_forget (((RECENT_FILE *) (GML_gl->data))->label);
-	      GML_malloc_forget (((RECENT_FILE *) (GML_gl->data)));
-	      GML_gl = GML_gl->next;
-	    }
-	}
-#endif
     }
   else
     {
       my_config = NULL;
     }
   g_string_free (conf_file, TRUE);
-#if defined(__DEBUG__)
-  GML_log_point (5, "Leaving init_config()");
-#endif
   return (my_config);
 }
