@@ -106,7 +106,7 @@ traverse_add_dir_to_clist (GNode * gn, gpointer data)
       if (fd->a_parent_node_is_vfs == IS_VFS)
 	temp[2] = g_strdup ("-");
       else
-	temp[2] = g_strdup (get_time (fd->date, my_config->date_format));
+	temp[2] = get_time (fd->date, my_config->date_format);
       temp[3] = folder_get_category_from_file_data (fd);
       if ((!temp[3]) || (fd->a_parent_node_is_vfs == IS_VFS))
 	temp[3] = nothing;
@@ -119,6 +119,8 @@ traverse_add_dir_to_clist (GNode * gn, gpointer data)
 
       i = gtk_clist_append (GTK_CLIST (clist), (gchar **) temp);
 
+      g_free ((gpointer) temp[1]);
+      g_free ((gpointer) temp[2]);
       if (is_dir (gn) == TRUE)
 	pix = my_config->default_dir_pix;
       else if (is_vfs_any (gn) == TRUE)
@@ -163,7 +165,7 @@ traverse_add_file_to_clist (GNode * gn, gpointer data)
 	  || (is_unreadable (gn) == TRUE))
 	temp[2] = g_strdup ("-");
       else
-	temp[2] = g_strdup (get_time (fd->date, my_config->date_format));
+	temp[2] = get_time (fd->date, my_config->date_format);
       temp[3] = folder_get_category_from_file_data (fd);
       if ((!temp[3]) || (fd->a_parent_node_is_vfs == IS_VFS))
 	temp[3] = nothing;
@@ -177,6 +179,8 @@ traverse_add_file_to_clist (GNode * gn, gpointer data)
 
       i = gtk_clist_append (GTK_CLIST (clist), (gchar **) temp);
 
+      g_free ((gpointer) temp[1]);
+      g_free ((gpointer) temp[2]);
       pix = get_pix_from_gnode (gn);
 
       gtk_clist_set_pixtext (GTK_CLIST (clist), i, 0,
@@ -191,7 +195,8 @@ traverse_add_file_to_clist (GNode * gn, gpointer data)
 /*****************************************************************************************/
 
 
-gint find_viewer (gpointer key, gpointer value, gpointer data)
+gint
+find_viewer (gpointer key, gpointer value, gpointer data)
 {
   struct mime_and_string *_find_mime = data;
   MIME_EXTENSIONS *m = value;
@@ -491,8 +496,7 @@ rm_tree (GNode * gn, FOLDER * racine)
   gtk_ctree_remove_node (GTK_CTREE (racine->ctree), fd->ctree_node);
 }
 
-gboolean
-set_vfs_fd (GNode * gn, gpointer data)
+gboolean set_vfs_fd (GNode * gn, gpointer data)
 {
   FILE_DATA *fd = get_file_data_from_gnode (gn);
   fd->a_parent_node_is_vfs = IS_VFS;
@@ -600,7 +604,8 @@ GnomeUIInfo clist_pressed_menu_file[] = {
   GNOMEUIINFO_END
 };
 
-gint cmp_2file_types (GNode * gn1, GNode * gn2)
+gint
+cmp_2file_types (GNode * gn1, GNode * gn2)
 {
   if (G_NODE_IS_ROOT (gn1->parent))
     return (-1);
@@ -781,14 +786,11 @@ set_currently_displayed_folder_pixtext (FOLDER * racine, gboolean is_open)
 				      NULL, NULL);
 	  gtk_ctree_node_set_pixtext (GTK_CTREE (racine->ctree),
 				      fd->ctree_node, 0,
-				      g_strdup (dir_text), 4, pix->pixmap,
-				      *(pix->mask));
-
+				      dir_text, 4, pix->pixmap, *(pix->mask));
 	  gn = gn->parent;
 
 	}
     }
-
 }
 
 /* Displays files and directories in the right window. */
@@ -817,7 +819,7 @@ list_folder (GNode * parent, gboolean expand_tree)
       if (fd->a_parent_node_is_vfs == IS_VFS)
 	temp[2] = g_strdup ("-");
       else
-	temp[2] = g_strdup (get_time (fd->date, my_config->date_format));
+	temp[2] = get_time (fd->date, my_config->date_format);
       temp[3] = folder_get_category_from_file_data (fd);
       if ((!temp[3]) || (fd->a_parent_node_is_vfs == IS_VFS))
 	temp[3] = nothing;
@@ -841,6 +843,9 @@ list_folder (GNode * parent, gboolean expand_tree)
 			     temp[0], 3, pix->pixmap, *(pix->mask));
       gtk_clist_set_row_data (GTK_CLIST (clist), i, parent);
 
+      g_free ((gpointer) temp[0]);
+      g_free ((gpointer) temp[1]);
+      g_free ((gpointer) temp[2]);
     }
 
   g_node_children_foreach (parent, G_TRAVERSE_ALL, traverse_add_dir_to_clist,
@@ -1125,34 +1130,52 @@ _gnome_add_file_menu (gchar * txt, gpointer data)
 }
 
 void
-update_file_menu ()
+empty_recentfile_menu ()
+{
+  gchar *path =
+    g_strconcat (GNOME_MENU_FILE_PATH, _("Recent files"), "/", NULL);
+
+  if (my_config->currently_displayed_recent_files)
+    gnome_app_remove_menus (GNOME_APP (main_window), path,
+			    my_config->currently_displayed_recent_files);
+
+  my_config->currently_displayed_recent_files = 0;
+  g_free (path);
+}
+
+void
+fill_recentfile_menu ()
 {
   gchar *path =
     g_strconcat (GNOME_MENU_FILE_PATH, _("Recent files"), "/", NULL);
-  gint n = g_list_length (my_config->recent_files);
   RECENT_FILE *rf;
   GList *gl;
 
-  if (n)
-    gnome_app_remove_menus (GNOME_APP (main_window), path, n);
-
+  if (my_config->currently_displayed_recent_files)
+    empty_recentfile_menu ();
   gl = my_config->recent_files;
+  my_config->currently_displayed_recent_files = 0;
   while (gl)
     {
       rf = gl->data;
       _gnome_add_file_menu (rf->label, rf->fullname);
+      my_config->currently_displayed_recent_files++;
       gl = g_list_next (gl);
     }
-    g_free(path);
+  g_free (path);
 }
 
 GList *
 add_file_to_recent_files (GList * recent_files, gint nb_max_recent_files,
-			  gchar * fullname)
+			  gchar * _fullname)
 {
   RECENT_FILE *rf;
+  GList *local_recent_files = recent_files;
   GList *gl;
   gchar *label;
+  gchar *fullname;
+
+  fullname = g_strdup(_fullname);
   if (fullname[0] != '/')
     label = g_strdup (fullname);
   else
@@ -1166,21 +1189,20 @@ add_file_to_recent_files (GList * recent_files, gint nb_max_recent_files,
       label = g_strdup (label);
     }
 
-
-  gl = recent_files;
+  gl = local_recent_files;
   /* Search for existing same entries */
   while (gl)
     {
       rf = gl->data;
       if (strcmp (rf->fullname, fullname) == 0)
 	{
-	  recent_files = g_list_remove_link (recent_files, gl);
+	  local_recent_files = g_list_remove_link (local_recent_files, gl);
 	  rf = gl->data;
 	  g_free (rf->label);
 	  g_free (rf->fullname);
 	  g_free (rf);
 	  g_list_free_1 (gl);
-	  gl = recent_files;
+	  gl = local_recent_files;
 	}
       else
 	{
@@ -1189,10 +1211,10 @@ add_file_to_recent_files (GList * recent_files, gint nb_max_recent_files,
     }
 
   /* No more than my_config->nb_max_recent_files entries */
-  while (g_list_length (recent_files) >= nb_max_recent_files)
+  while (g_list_length (local_recent_files) >= nb_max_recent_files)
     {
-      gl = g_list_last (recent_files);
-      recent_files = g_list_remove_link (recent_files, gl);
+      gl = g_list_last (local_recent_files);
+      local_recent_files = g_list_remove_link (local_recent_files, gl);
       rf = gl->data;
       g_free (rf->label);
       g_free (rf->fullname);
@@ -1203,18 +1225,26 @@ add_file_to_recent_files (GList * recent_files, gint nb_max_recent_files,
   /* Add the new entry */
   rf = (RECENT_FILE *) g_malloc (sizeof (RECENT_FILE));
   rf->label = label;
-  rf->fullname = g_strdup (fullname);
-  recent_files = g_list_prepend (recent_files, rf);
-  return (recent_files);
+  rf->fullname = fullname;
+  local_recent_files = g_list_prepend (local_recent_files, rf);
+  return (local_recent_files);
 }
 
 void
 add_file_menu (gchar * fullname)
 {
+#if defined(__DEBUG__)
+  GML_set_mode_active ();
+  GML_log_point (1, "add_file_menu");
+#endif
+  empty_recentfile_menu ();
   my_config->recent_files =
     add_file_to_recent_files (my_config->recent_files,
 			      my_config->nb_max_recent_files, fullname);
-  update_file_menu ();
+  fill_recentfile_menu ();
+#if defined(__DEBUG__)
+  GML_set_mode_passive ();
+#endif
 }
 
 void
@@ -1235,9 +1265,6 @@ build_gui (void)
   GtkWidget *main_vbox;
   GtkWidget *appbar1;
 
-#if defined(__DEBUG__)
-GML_log_point(5,"Entering build_gui()");
-#endif
 /* Main vertical box */
   main_vbox = gtk_vbox_new (FALSE, 1);
   gtk_container_border_width (GTK_CONTAINER (main_vbox), 1);
@@ -1250,7 +1277,7 @@ GML_log_point(5,"Entering build_gui()");
   enable_gnome_button_bar (main_window, NULL);
   gtk_menu_item_right_justify (GTK_MENU_ITEM (menubar[3].widget));
   menus_set_sensitive (FALSE);
-  update_file_menu ();
+  fill_recentfile_menu ();
 
 /* Status and progress bar */
   appbar1 = gnome_appbar_new (TRUE, TRUE, GNOME_PREFERENCES_NEVER);
@@ -1294,9 +1321,6 @@ GML_log_point(5,"Entering build_gui()");
 
   gtk_paned_add1 (GTK_PANED (hpaned), ctree_window);
 
-#if defined(__DEBUG__)
-GML_log_point(5,"Leaving build_gui()");
-#endif
 }
 
 void
