@@ -112,8 +112,8 @@ write_vfsnode (GNode * gn, gpointer data)
   gzwrite_gstring (fd->name, gzcatalog);
   le = GUINT_TO_LE (fd->type);
   gzwrite (gzcatalog, &le, sizeof (guint));
-  pb = progress_getCurrent () + 1;
-  progress_setCurrent (pb);
+  pb = progress_getCurrent (GNOMEAPPBAR_MAIN) + 1;
+  progress_setCurrent (pb, GNOMEAPPBAR_MAIN);
 #if !defined(USE_PTHREADS)
   gui_update ();
 #endif
@@ -181,8 +181,8 @@ write_filedata (FILE_DATA * d, gzFile fh)
       if (d->mime->len)
 	gzwrite_gstring (d->mime, fh);
     }
-  pb = progress_getCurrent () + 1;
-  progress_setCurrent (pb);
+  pb = progress_getCurrent (GNOMEAPPBAR_MAIN) + 1;
+  progress_setCurrent (pb, GNOMEAPPBAR_MAIN);
 #if !defined(USE_PTHREADS)
   gui_update ();
 #endif
@@ -283,8 +283,8 @@ _save_cat_to_file_ (void *arg)
 	{
 	  gzwrite_gstring (g_ptr_array_index (racine->descriptions, i),
 			   gzcatalog);
-	  pb = progress_getCurrent () + 1;
-	  progress_setCurrent (pb);
+	  pb = progress_getCurrent (GNOMEAPPBAR_MAIN) + 1;
+	  progress_setCurrent (pb, GNOMEAPPBAR_MAIN);
 #if !defined(USE_PTHREADS)
 	  gui_update ();
 #endif
@@ -301,8 +301,8 @@ _save_cat_to_file_ (void *arg)
 	{
 	  gzwrite_gstring (g_ptr_array_index (racine->categories, i),
 			   gzcatalog);
-	  pb = progress_getCurrent () + 1;
-	  progress_setCurrent (pb);
+	  pb = progress_getCurrent (GNOMEAPPBAR_MAIN) + 1;
+	  progress_setCurrent (pb, GNOMEAPPBAR_MAIN);
 #if !defined(USE_PTHREADS)
 	  gui_update ();
 #endif
@@ -369,7 +369,8 @@ save_cat_to_file (char *filename, FOLDER * racine)
   folder_statistics (racine, racine->tree, &nb_desc, &nb_cat,
 		     &nb_disks, NULL, &nb_dirs, NULL, &nb_files, NULL, NULL,
 		     NULL);
-  progress_setTotal (nb_desc + nb_cat + nb_dirs + nb_files + nb_disks);
+  progress_setTotal (nb_desc + nb_cat + nb_dirs + nb_files + nb_disks,
+		     GNOMEAPPBAR_MAIN);
 
   set_thread_status_to_running ();
   progress_timeout (NULL);
@@ -386,10 +387,10 @@ save_cat_to_file (char *filename, FOLDER * racine)
     }
   else
     {
-      thread_gtk_timeout_with_progress_bar (NULL);
+      thread_gtk_timeout_with_progress_bar (GINT_TO_POINTER(GNOMEAPPBAR_MAIN));
     }
 #else
-  thread_gtk_timeout_with_progress_bar (NULL);
+  thread_gtk_timeout_with_progress_bar (GINT_TO_POINTER(GNOMEAPPBAR_MAIN));
   _save_cat_to_file_ (&_save_args_);
 #endif
   return (0);
