@@ -15,9 +15,18 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
-#ifndef TRUCMUCHE_H__
-#define TRUCMUCHE_H__
+#ifndef __SAVECAT_H__
+#define __SAVECAT_H__
 
-int save_cat_to_file(char *filename);
+#include <zlib.h>
+
+#include "config_common.h"
+
+void gzwrite_gstring (GString * g, gzFile fh);
+void write_gstring (GString * g, int fh);
+void write_filedata (FILE_DATA * d, gzFile fh);
+void write_subdir (GNode * gn);
+void write_gnode (GNode * gn, gpointer data);
+int save_cat_to_file (char *filename, FOLDER * racine);
 
 #endif
