@@ -169,7 +169,7 @@ find_files (GNode * gn, gpointer data)
 
   progress_setCurrent (progress_getCurrent (GNOMEAPPBAR_SEARCH) + 1,
 		       GNOMEAPPBAR_SEARCH);
-  progress_timeout (GINT_TO_POINTER (GNOMEAPPBAR_SEARCH));
+  progress_createTimeout (GINT_TO_POINTER (GNOMEAPPBAR_SEARCH));
   while (gtk_events_pending ())
     gtk_main_iteration ();
 
@@ -334,7 +334,6 @@ simply_find_files (GNode * gn, gpointer data)
 
   progress_setCurrent (progress_getCurrent (GNOMEAPPBAR_SEARCH) + 1,
 		       GNOMEAPPBAR_SEARCH);
-  progress_timeout (GINT_TO_POINTER (GNOMEAPPBAR_SEARCH));
   while (gtk_events_pending ())
     gtk_main_iteration ();
 
@@ -403,6 +402,7 @@ start_search (FOLDER * racine, GNodeTraverseFunc cb_find_files)
 		     GNOMEAPPBAR_SEARCH);
   progress_setCurrent (0, GNOMEAPPBAR_SEARCH);
   progress_setStatus (_("Searching..."), GNOMEAPPBAR_SEARCH);
+  progress_createTimeout (GINT_TO_POINTER (GNOMEAPPBAR_SEARCH));
 
   g_node_traverse (SEARCH_OPTIONS_search_root, G_PRE_ORDER, G_TRAVERSE_ALL,
 		   -1, cb_find_files, racine);
